Class: WorkOS::Types::EventStruct
- Inherits:
-
T::Struct
- Object
- T::Struct
- WorkOS::Types::EventStruct
- Defined in:
- lib/workos/types/event_struct.rb
Overview
The EventStruct acts as a typed interface for the Event class
The EventStruct acts as a typed interface for the Event class