Class: WorkOS::Types::RequestOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/workos/types/request_options.rb

Overview

Documentation-only class describing the per-request override keys accepted by every generated service method via the ‘request_options` keyword argument.

Instance Attribute Summary collapse

Instance Attribute Details

#api_keyString? (readonly)

Returns Override the client-level API key for this request.

Returns:

  • (String, nil)

    Override the client-level API key for this request.



28
29
30
31
# File 'lib/workos/types/request_options.rb', line 28

class RequestOptions
  # This class is never instantiated — it exists solely for YARD
  # documentation. Service methods accept a plain Hash.
end

#base_urlString? (readonly)

Returns Override the base URL for this request.

Returns:

  • (String, nil)

    Override the base URL for this request.



28
29
30
31
# File 'lib/workos/types/request_options.rb', line 28

class RequestOptions
  # This class is never instantiated — it exists solely for YARD
  # documentation. Service methods accept a plain Hash.
end

#extra_headersHash{String => String}? (readonly)

Returns Additional HTTP headers to send with this request.

Returns:

  • (Hash{String => String}, nil)

    Additional HTTP headers to send with this request.



28
29
30
31
# File 'lib/workos/types/request_options.rb', line 28

class RequestOptions
  # This class is never instantiated — it exists solely for YARD
  # documentation. Service methods accept a plain Hash.
end

#idempotency_keyString? (readonly)

Returns Set a custom Idempotency-Key header for this request.

Returns:

  • (String, nil)

    Set a custom Idempotency-Key header for this request.



28
29
30
31
# File 'lib/workos/types/request_options.rb', line 28

class RequestOptions
  # This class is never instantiated — it exists solely for YARD
  # documentation. Service methods accept a plain Hash.
end

#max_retriesInteger? (readonly)

Returns Override the maximum number of retries for this request.

Returns:

  • (Integer, nil)

    Override the maximum number of retries for this request.



28
29
30
31
# File 'lib/workos/types/request_options.rb', line 28

class RequestOptions
  # This class is never instantiated — it exists solely for YARD
  # documentation. Service methods accept a plain Hash.
end

#timeoutInteger? (readonly)

Returns Override the HTTP timeout (seconds) for this request.

Returns:

  • (Integer, nil)

    Override the HTTP timeout (seconds) for this request.



28
29
30
31
# File 'lib/workos/types/request_options.rb', line 28

class RequestOptions
  # This class is never instantiated — it exists solely for YARD
  # documentation. Service methods accept a plain Hash.
end