Class: WorkOS::Types::WebhookStruct
- Inherits:
-
T::Struct
- Object
- T::Struct
- WorkOS::Types::WebhookStruct
- Defined in:
- lib/workos/types/webhook_struct.rb
Overview
This WebhookStruct acts as a typed interface for the Webhook class
This WebhookStruct acts as a typed interface for the Webhook class