Module: WorkOS::Types::WidgetScope

Defined in:
lib/workos/types/widget_scope.rb

Overview

The WidgetScope constants are declarations of a fixed set of values for scopes while generating a widget token.

Constant Summary collapse

USERS_TABLE_MANAGE =
'widgets:users-table:manage'
SSO_MANAGE =
'widgets:sso:manage'
DOMAIN_VERIFICATION_MANAGE =
'widgets:domain-verification:manage'
ALL =
[USERS_TABLE_MANAGE, SSO_MANAGE, DOMAIN_VERIFICATION_MANAGE].freeze